from discord_logger import DiscordLogger
from os import environ

def send_message_discord(message, metadata={}, interface_name="ga", level="error", title="Exception raised", description=" "):
    """
    Sends a message to a discord channel.

    Args:
        message (string): the message to be sent.
        metadata (dictionary): Any dictionary with information.
        interface_name (string): The name of the interface
        level (string): The level of the information being sent. Default is "error". Possibilities: error, warn, info, verbose, debug, success.
        title (string): Title of the message.
        description (string): Description of the message.
    """    

    options = {
        "application_name": "Raptor",
        "service_name": f"{interface_name}",
        "service_environment": "Production",
        "default_level": "info",
    }

    logger = DiscordLogger(webhook_url=environ.get('DISCORD_WEBHOOK'), **options)
    logger.construct(
        title=f"{title}",
        level=f"{level}",
        description=f"{description}",
        error=message,
        metadata=metadata,
    )

    response = logger.send()

    pass


"""Core module for AWS S3 related operations"""
from sallron.util import settings
from functools import wraps
import pickle
import boto3
import os

def _aws_auth(f):

    @wraps(f)
    def decorator(*args, **kwargs):

        if not (settings.AWS_ACCESS_KEY_ID and settings.AWS_SECRET_ACCESS_KEY_ID and settings.AWS_REGION and settings.LOGGING_BUCKET):
            auth = False
        else:
            auth = True

        return f(auth, *args, **kwargs)
    
    return decorator

@_aws_auth
def get_bucket(aws_auth):
    if aws_auth:
        s3 = boto3.session.Session(
            aws_access_key_id=settings.AWS_ACCESS_KEY_ID,
            aws_secret_access_key=settings.AWS_SECRET_ACCESS_KEY_ID
        ).resource("s3", region_name=settings.AWS_REGION)
        return s3.Bucket(settings.LOGGING_BUCKET)
    else:
        print('AWS credentials not set.')
        return None

def send_to_s3(obj_path):
    """
    Utility function to send objects to S3

    Args:
        aws_auth (bool): Boolean indicating whether AWS settings were set or not
        obj_path (str): Path to object to be sent
    """

    # ensure everything needed is set
    if os.path.exists(obj_path):

        bucket = get_bucket()

        try:
            # note it expects a obj_path following path/to/obj.txt format!
            # gets the last name of this sequence
            bucket.upload_file(obj_path, obj_path.split('/')[-1])

            # remove the current log file
            os.remove(obj_path)
        except:
            pass

    else:
        print('File path not found.')
        pass


#!/usr/bin/env python

MONGO_CONN_STR = "mongodb+srv://..."

ADMIN_COLLECTION = "info" # collection containing credentials and function parameters

ADMIN_DATABASES = ["admin", "local", "temporary-tokens"] # databases to ignore when fetching customers

_WEBHOOK = ""

TIMEZONE = "America/Sao_Paulo" # timezone for restarting and acquiring load_time_block 

OS = 'UBUNTU'
# OS = 'MAC'

SAVE_LOGS = False

LOG_DIR = "logs/"

MAX_LOG_SIZE = 100000000 # 100Mb

MAX_LOG_BACKUPS = 5

# AWS CONFIG
AWS_ACCESS_KEY_ID = ""
AWS_SECRET_ACCESS_KEY_ID = ""
AWS_REGION = "us-east-2"
LOGGING_BUCKET = "raptor-logs"



from sallron.util import s3
import schedule
import datetime
import pytz
import sys

def _send_to_s3_and_kill(log_dir):
    """
    Utility function to send the log to s3 and kill the process

    Args:
        log_dir (str): Directory containing log to be sent
    """

    s3.send_to_s3(log_dir)

    sys.exit("Exiting from process after send log to S3.")

def schedule_log_sending_and_kill_process(log_dir, timezone):
    """
    Utility function to schedule the sending of log file to S3 and kill the hole process
    Args:
        obj_path (str): Path to object to be sent
        timezone (str): Timezone string supported by pytz
    """

    schedule.every().day.at(
        datetime.time(hour=0, minute=1, tzinfo=pytz.timezone(timezone)).strftime("%H:%M")
    ).do(_send_to_s3_and_kill, log_dir=log_dir)